@@ -1,5 +1,5 @@
 package Adapter::Async::OrderedList;
-$Adapter::Async::OrderedList::VERSION = '0.016';
+$Adapter::Async::OrderedList::VERSION = '0.017';
 use strict;
 use warnings;
 
@@ -11,7 +11,7 @@ Adapter::Async::OrderedList - API for dealing with ordered lists
 
 =head1 VERSION
 
-version 0.015
+version 0.017
 
 =head1 DESCRIPTION
 
@@ -158,7 +158,7 @@ sub push {
 	my $f;
 	$f = $self->count->then(sub {
 		my $count = shift;
-		$self->splice(shift, 0, $data)->transform(
+		$self->splice($count, 0, $data)->transform(
 			done => sub {
 				($count, @_)
 			}
